from Products.MailmanAdaptor.interfaces.MailmanMember import IMailmanMember
from Products.Archetypes.public import ComputedField, IntegerField
from Products.Archetypes.public import SelectionWidget
from Products.Archetypes.public import registerType
from Products.Archetypes.ExtensibleMetadata import ExtensibleMetadata
from Products.Archetypes.public import Schema
import time

from Products.CMFMember.Member import Member
from Products.CMFMember.Member import id_schema , contact_schema , \
                                      security_schema , login_info_schema, \
                                      plone_schema
from Products.MailmanAdaptor.Permissions import ADD_CONTENTS_PERMISSION, \
                                                VIEW_PUBLIC_PERMISSION, \
                                                EDIT_ID_PERMISSION
                                                
from Products.MailmanAdaptor.config import PROJECTNAME, ENABLED, DELIVERY_STATUS

from Products.Archetypes.debug import log

mailman_schema = Schema((
    IntegerField('deliveryStatus',
        default=ENABLED,
        vocabulary=DELIVERY_STATUS,
        widget=SelectionWidget(format='select', visible={'edit':'invisible', 'view':'invisible'}
        )
    ),
    ComputedField('deliveryStatusChangeTime',
        expression="context._deliveryStatusChangeTime"),
))

content_schema = id_schema +  contact_schema + plone_schema + security_schema \
                 + login_info_schema

class MailmanMember(Member):
    """Mailman Member Class"""
    
    __implements__ = Member.__implements__ + (IMailmanMember,)

    archetype_name = portal_type = meta_type = 'MailmanMember'
    
    schema = content_schema + ExtensibleMetadata.schema + mailman_schema

    def __init__(self, userid):
        Member.__init__(self, userid)
        self._deliveryStatusChangeTime = 0
    
    #Override the getSchema method 
    def getSchema(self):
        return self.schema

    def setDeliveryStatus(self, value, **kw):
        """ override to set deliveryStatusChangeTime at the same time
        """
        if int(value) == ENABLED:
            self._deliveryStatusChangeTime = 0
        else:
            self._deliveryStatusChangeTime = time.time()

        self.getField('deliveryStatus').set(self, value, **kw)

registerType(MailmanMember, PROJECTNAME)
